"""
Kodexa Platform
----------

Provides out of the box integration with the Kodexa platform, enabling the universe of content services that are available
"""
from .kodexa import RemoteSession, RemotePipeline, RemoteAction, KodexaPlatform
